''' Updated 3/21/2023
    For ArcGIS Pro
    This script creates mailing lists for an area of interest.
    Data sources:
        - Mailing Address Points (Assessor's parcels, CAMS addresses and USPS addresses)
    Parameters:
        - The area of interest (Must be a shapefile)
        - The workspace (Must be a folder where all outputs will be written to)
'''

import sys, arcpy, os


# Data source 
src_addr_pnts = r"P:\mppub\MAPSVCS\CUSTOM_MAPS\MAILING_LISTS\WORKSPACE\eGIS_Addressing.sde\eGIS_Addressing.EGIS.DPW_MAILING_ADDRESS_POINTS"
##src_cams_addr = r"\\159.83.112.39\gis01$\members\Database Connections\eGIS_Addressing on EGISDBP1 as viewer.sde\eGIS_Addressing.EGIS.CAMS_ADDRESS_POINTS"

# Get user inputs
AIO = arcpy.GetParameterAsText(0)
output_folder = arcpy.GetParameterAsText(1)
area_of_interest = os.path.basename(AIO)[:-4]

# Create workspace
arcpy.management.CreateFileGDB(output_folder, os.path.basename(AIO)[:-4] + ".gdb")
fgdb = output_folder + "\\" + os.path.basename(AIO)[:-4] + ".gdb"
arcpy.env.workspace = fgdb

# Create layers and select address points within the area of interest
arcpy.management.MakeFeatureLayer(AIO, "lyr_AIO")
arcpy.management.MakeFeatureLayer(src_addr_pnts, "lyr_addr_pnts")
arcpy.management.SelectLayerByLocation("lyr_addr_pnts", "INTERSECT", "lyr_AIO", "", "NEW_SELECTION")
                                  
# Export data to workspace
select_addr_pnts = "Mail_Addr_4_" + area_of_interest
arcpy.management.CopyFeatures("lyr_addr_pnts", select_addr_pnts)

# Create mailing list for the area of interest
mail_addr = "tbl_Mail_Addr_4_" + area_of_interest

arcpy.conversion.TableToTable("lyr_addr_pnts", fgdb, mail_addr, "",
                              "AIN \"AIN\" true true false 10 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,AIN,0,10;\
                              HouseNo \"HouseNo\" true true false 7 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,HouseNo,0,7;\
                              Fraction \"Fraction\" true true false 3 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,Fraction,0,3;\
                              Direction \"Direction\" true true false 1 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,Direction,0,1;\
                              Unit \"Unit\" true true false 20 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,Unit,0,20;\
                              Street \"Street\" true true false 50 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,Street,0,50;\
                              Address \"Address\" true true false 80 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,Address,0,80;\
                              City \"City\" true true false 30 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,City,0,30;\
                              ZIP \"ZIP\" true true false 10 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,ZIP,0,10;\
                              Owner \"Owner\" true true false 131 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,Owner,0,131;\
                              Source \"Source\" true true false 10 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,Source,0,10;\
                              Type \"Type\" true true false 20 Text 0 0,First,#,mailing_addresses_4_Quartz_Hill,Type,0,20", config_keyword="")[0]

arcpy.management.DeleteIdentical(mail_addr, fields=["Address"], xy_tolerance="", z_tolerance=0)[0]
mail_list = output_folder + "\\Mailing_List_4_" + area_of_interest + ".xls"

arcpy.conversion.TableToExcel(mail_addr, mail_list, "NAME", "CODE")

# Delete temporary files
arcpy.Delete_management(mail_addr)
temp_layers = ["AIO", "lyr_addr_pnts"]
for layer in temp_layers:
    if arcpy.Exists(layer):
        arcpy.Delete_management(layer)
      

